@@ -172,7 +172,8 @@ def singledispatch(func):  # noqa: C901
     # There are many programs that use functools without singledispatch, so we
     # trade-off making singledispatch marginally slower for the benefit of
     # making start-up of such applications slightly faster.
-    import types, weakref  # noqa: E401
+    import types  # noqa: E401
+    import weakref
 
     registry = {}
     dispatch_cache = weakref.WeakKeyDictionary()
